﻿/*
 * Author: G. Monz (DK7IO), 2012-04-29
 * This file is distributed without any warranty.
 * */

using System;
using System.Text;
using System.Collections.Generic;

namespace RadioMobile
{
	public abstract class RM_NetFile
	{
		IList<RMNet> _nets;
		public IList<RMNet> Nets
		{
			get
			{
				return _nets;
			}
			set
			{
				_nets = value;
			}
		}

		IList<RMUnit> _units;
		public IList<RMUnit> Units
		{
			get
			{
				return _units;
			}
			set
			{
				_units = value;
			}
		}

		IList<RMSystem> _systems;
		public IList<RMSystem> Systems
		{
			get
			{
				return _systems;
			}
			set
			{
				_systems = value;
			}
		}

		RMCoverage _coverage;
		public RMCoverage Coverage
		{
			get
			{
				return _coverage;
			}
			set
			{
				_coverage = value;
			}
		}

		Byte[,] _netRoles;
		public Byte[,] NetRoles
		{
			get
			{
				return _netRoles;
			}
			set
			{
				_netRoles = value;
			}
		}

		Byte[,] _netSystems;
		public Byte[,] NetSystems
		{
			get
			{
				return _netSystems;
			}
			set
			{
				_netSystems = value;
			}
		}

		Single[,] _netAntennaHeights;
		public Single[,] NetAntennaHeights //m
		{
			get
			{
				return _netAntennaHeights;
			}
			set
			{
				_netAntennaHeights = value;
			}
		}

		Byte[] _unitIcons;
		public Byte[] UnitIcons
		{
			get
			{
				return _unitIcons;
			}
			set
			{
				_unitIcons = value;
			}
		}

		Single[] _additionalCableLossesPerMeter;
		public Single[] AdditionalCableLossesPerMeter //dB
		{
			get
			{
				return _additionalCableLossesPerMeter;
			}
			set
			{
				_additionalCableLossesPerMeter = value;
			}
		}

		public RM_NetFile()
		{
		}

		public void SetNetRoles(Byte netRole)
		{
			int countNets = Nets.Count;
			int countUnits = Units.Count;

			NetRoles = new Byte[countNets, countUnits];

			for (int netIndex = 0; netIndex < countNets; netIndex++)
			{
				for (int unitIndex = 0; unitIndex < countUnits; unitIndex++)
				{
					NetRoles[netIndex, unitIndex] = netRole;
				}
			}
		}

		public void SetNetSystems(Byte systemNumber)
		{
			int countNets = Nets.Count;
			int countUnits = Units.Count;

			NetSystems = new Byte[countNets, countUnits];

			for (int netIndex = 0; netIndex < countNets; netIndex++)
			{
				for (int unitIndex = 0; unitIndex < countUnits; unitIndex++)
				{
					NetSystems[netIndex, unitIndex] = systemNumber;
				}
			}
		}

		public void SetNetAntennaHeights(Single unitAntennaHeight)
		{
			int countNets = Nets.Count;
			int countUnits = Units.Count;

			NetAntennaHeights = new Single[countNets, countUnits];

			for (int netIndex = 0; netIndex < countNets; netIndex++)
			{
				for (int unitIndex = 0; unitIndex < countUnits; unitIndex++)
				{
					NetAntennaHeights[netIndex, unitIndex] = unitAntennaHeight;
				}
			}
		}

		public void SetUnitIcons(Byte unitIcon)
		{
			int countUnits = Units.Count;

			UnitIcons = new Byte[countUnits];

			for (int i = 0; i < countUnits; i++)
			{
				UnitIcons[i] = unitIcon;
			}
		}

		public void SetAdditionalCableLossesPerMeter(Single additionalCableLossPerMeter)
		{
			int countUnits = Units.Count;

			AdditionalCableLossesPerMeter = new Single[countUnits];

			for (int i = 0; i < countUnits; i++)
			{
				AdditionalCableLossesPerMeter[i] = additionalCableLossPerMeter;
			}
		}

		public abstract void Save(string fileName);
	}
}