﻿/*
 * Author: G. Monz (DK7IO), 2012-04-29
 * This file is distributed without any warranty.
 * */

using System;
using System.Drawing;

namespace RadioMobile
{
	public static class Utilities
	{
		public static Int32 GetColorNumber(Color color)
		{
			Int32 result = GetColorNumber(color.R, color.G, color.B);

			return result;
		}

		public static Int32 GetColorNumber(Byte red, Byte green, Byte blue)
		{
			Int32 result =
				red +
				green * (Int32)Math.Pow(2, 8) +
				blue * (Int32)Math.Pow(2, 16)
			;

			return result;
		}

		public static Byte ParseByte(bool value)
		{
			Byte result = (
				value ?
				(Byte)1 :
				(Byte)0
			);

			return result;
		}

		public static Int16 ParseInt16(bool value)
		{
			Int16 result = (
				value ?
				(Int16)1 :
				(Int16)0
			);

			return result;
		}

		public static String Left(String text, int length)
		{
			String result;

			if (IsEmpty(text))
			{
				result = text;
			}
			else
			{
				result = text.Substring(0, Math.Min(Math.Max(0, length), text.Length));
			}

			return result;
		}

		public static String PadRight(String text, int length, bool cutIfLonger)
		{
			String result = string.Empty;

			if (text != null)
			{
				if (cutIfLonger)
				{
					result = Left(text, length).PadRight(length);
				}
				else
				{
					result = text.PadRight(length);
				}
			}

			return result;
		}

		/// <summary>
		/// Prüft, ob ein <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// </summary>
		/// <param name="text">Der zu prüfende <see cref="String" />.</param>
		/// <returns>
		/// True, wenn der zu prüfende <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// Sonst false.
		/// </returns>
		public static bool IsEmpty(string text)
		{
			bool result = string.IsNullOrEmpty(text);

			return result;
		}

		/// <summary>
		/// Prüft, ob ein <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// </summary>
		/// <param name="text">Der zu prüfende <see cref="String" />.</param>
		/// <param name="trim">
		/// True, wenn vor der Prüfung führende und folgende Leerzeichen abgeschnitten werden sollen.
		/// Sonst false.
		/// </param>
		/// <returns>
		/// True, wenn der zu prüfende <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// Sonst false.
		/// </returns>
		public static bool IsEmpty(string text, bool trim)
		{
			bool result = true;

			if (!IsEmpty(text))
			{
				result = (
					trim ?
					IsEmpty(text.Trim()) :
					false
				);
			}

			return result;
		}
	}
}